Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(970)

Unified Diff: chrome/browser/predictors/resource_prefetch_predictor.h

Issue 2538743002: predictors: Add a origin for prefetch requests, remove the URL/host settings. (Closed)
Patch Set: . Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/predictors/resource_prefetch_predictor.h
diff --git a/chrome/browser/predictors/resource_prefetch_predictor.h b/chrome/browser/predictors/resource_prefetch_predictor.h
index 85b2ce270e553cf13b1ae6a119ab1cb1d00ec7b3..d4a0065d57f8ec01a19b842eac69fa269d396235 100644
--- a/chrome/browser/predictors/resource_prefetch_predictor.h
+++ b/chrome/browser/predictors/resource_prefetch_predictor.h
@@ -151,9 +151,9 @@ class ResourcePrefetchPredictor
// Called when the main frame of a page completes loading.
void RecordMainFrameLoadComplete(const NavigationID& navigation_id);
- // Starts prefetching if it is enabled and prefetching data exists for the
- // |main_frame_url| either at the URL or at the host level.
- void StartPrefetching(const GURL& main_frame_url);
+ // Starts prefetching if it is enabled for |origin| and prefetching data
+ // exists for the |main_frame_url| either at the URL or at the host level.
+ void StartPrefetching(const GURL& main_frame_url, PrefetchOrigin origin);
// Stops prefetching that may be in progress corresponding to
// |main_frame_url|.

Powered by Google App Engine
This is Rietveld 408576698